"""Top-level package for COVID-19 Outbreak Simulator."""

__author__ = """COVID-19 Outbreak Simulator"""
__email__ = 'bo.peng@bcm.edu'
__version__ = '0.5.1'